﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.ComponentModel.DataAnnotations;
using System.Web.Mvc;
using System.Text.RegularExpressions;

namespace MVCCornucopia.Common
{

    public class UrlAttribute : RequiredAttribute, IClientValidatable
    {
        private static readonly Regex emailRegex = new Regex(@"(http|ftp|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&amp;:/~\+#]*[\w\-\@?^=%&amp;/~\+#])?");


        public UrlAttribute()
        {
            ErrorMessage = "Enter a valid url!";
        }

        public override bool IsValid(object value)
        {
            return !string.IsNullOrEmpty((string)value) &&
                emailRegex.IsMatch((string)value);
        }

        public IEnumerable<ModelClientValidationRule> GetClientValidationRules(
            ModelMetadata metadata, ControllerContext context)
        {

            return new List<ModelClientValidationRule> {
            new ModelClientValidationRule {
                ValidationType = "url",
                ErrorMessage = this.ErrorMessage
            },
            new ModelClientValidationRule {
                ValidationType = "required",
                ErrorMessage = this.ErrorMessage
            }
        };
        }
    }

}